﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace TechNote15_DateTimeSetting_CS
{
    public partial class DateTimeSetting : Form
    {
        private DATETIMEINFOS m_dateTimeInfo;
        private DateTime m_dateTime;
        private DialogResult m_dialogResult;

        // 폼에 설정된 날짜를 구조체 형식로 가져오기
        public DATETIMEINFOS DateTimeInfo
        {
            get
            {
                return m_dateTimeInfo;
            }
        }

        // 폼에 설정된 날짜를 DateTime 형식으로 가져오기
        public DateTime DateTime
        {
            get
            {
                return m_dateTime;
            }
        }

        // 폼 다이얼로그 결과를 가져오기
        public new DialogResult DialogResult
        {
            get
            {
                return m_dialogResult;
            }
        }

        // 생성자에서 현재 날짜을 읽어오거나 설정한 날짜를 저장합니다.
        public DateTimeSetting()
        {
            InitializeComponent();

            m_dateTime = DateTime.Now;
        }

        public DateTimeSetting(DateTime dateTime)
        {
            InitializeComponent();

            m_dateTime = dateTime;
        }

        private void DateTimeSetting_Load(object sender, EventArgs e)
        {
            // 버튼 클릭 후 RepeatInterval마다 Click Event가 발생하게 됩니다.
            udYear.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            // 입력할 수 있는 최소/최대 값
            udYear.Minimum = 2000;
            udYear.Maximum = 2500;
            // 특수 기능 REPT에서 반복 입력 시간 간격을 정합니다.
            udYear.RepeatInterval = 100;

            udMonth.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            udMonth.Minimum = 1;
            udMonth.Maximum = 12;
            udMonth.RepeatInterval = 100;

            udDate.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            udDate.Minimum = 1;
            udDate.Maximum = DateTime.DaysInMonth(m_dateTime.Year, m_dateTime.Month);
            udDate.RepeatInterval = 100;

            udHour.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            udHour.Minimum = 0;
            udHour.Maximum = 23;
            udHour.RepeatInterval = 100;

            udMinute.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            udMinute.Minimum = 0;
            udMinute.Maximum = 59;
            udMinute.RepeatInterval = 100;

            udSecond.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            udSecond.Minimum = 0;
            udSecond.Maximum = 59;
            udSecond.RepeatInterval = 100;

            // 초기값 설정
            SetValues(m_dateTime);

            m_dialogResult = DialogResult.None;
        }

        private void btnSet_Click(object sender, EventArgs e)
        {
            // 전달할 결과값 설정
            m_dateTimeInfo.strYear = udYear.Value.ToString();
            m_dateTimeInfo.strMonth = udMonth.Value.ToString();
            m_dateTimeInfo.strDate = udDate.Value.ToString();
            m_dateTimeInfo.strHour = udHour.Value.ToString();
            m_dateTimeInfo.strMinute = udMinute.Value.ToString();
            m_dateTimeInfo.strSecond = udSecond.Value.ToString();

            m_dialogResult = DialogResult.OK;

            m_dateTime = new DateTime((int)udYear.Value, (int)udMonth.Value, (int)udDate.Value,
                                      (int)udHour.Value, (int)udMinute.Value, (int)udSecond.Value);

            // 현재 시스템의 날짜 및 시간을 설정
            smartConfigs1.ControlPanel.SetSystemDateTime(m_dateTime);
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            SetValues(m_dateTime);
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void udMonth_OnButtonClick(object sender, EventArgs e)
        {
            SetMaxDate();
        }

        // 지정된 DateTime으로 값을 설정
        private void SetValues(DateTime dateTime)
        {
            udYear.Value = dateTime.Year;
            udMonth.Value = dateTime.Month;

            SetMaxDate();

            udDate.Value = dateTime.Day;
            udHour.Value = dateTime.Hour;
            udMinute.Value = dateTime.Minute;
            udSecond.Value = dateTime.Second;
        }

        // Date가 최대 일수를 넘지 않도록 설정 
        private void SetMaxDate()
        {
            int iMaxDate = DateTime.DaysInMonth((int)udYear.Value, (int)udMonth.Value);
            udDate.Maximum = iMaxDate;

            if ((int)udDate.Value > iMaxDate)
            {
                udDate.Value = iMaxDate;
            }
        }
    }
}