﻿Public Class DateTimeSetting

    Private m_dateTimeInfo As DATETIMEINFOS
    Private m_dateTime As DateTime
    Private m_dialogResult As DialogResult

    ' 폼에 설정된 날짜를 구조체 형식로 가져오기
    Public ReadOnly Property DateTimeInfo() As DATETIMEINFOS
        Get
            Return m_dateTimeInfo
        End Get
    End Property

    ' 폼에 설정된 날짜를 DateTime 형식으로 가져오기
    Public ReadOnly Property DateTime() As DateTime
        Get
            Return m_dateTime
        End Get
    End Property

    ' 폼 다이얼로그 결과를 가져오기
    Public Overloads ReadOnly Property DialogResult() As DialogResult
        Get
            Return m_dialogResult
        End Get
    End Property

    Public Sub New()
        InitializeComponent()
        m_dateTime = Date.Now
    End Sub

    Public Sub New(ByVal dateTime As DateTime)
        InitializeComponent()
        m_dateTime = dateTime
    End Sub

    Private Sub DateTimeSetting_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ' 버튼 클릭 후 RepeatInterval마다 Click Event가 발생하게 됩니다.
        udYear.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT
        ' 입력할 수 있는 최소/최대 값
        udYear.Minimum = 2000
        udYear.Maximum = 2500
        ' 특수 기능 REPT에서 반복 입력 시간 간격을 정합니다.
        udYear.RepeatInterval = 100

        udMonth.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT
        udMonth.Minimum = 1
        udMonth.Maximum = 12
        udMonth.RepeatInterval = 100

        udDate.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT
        udDate.Minimum = 1
        udDate.Maximum = Date.DaysInMonth(m_dateTime.Year, m_dateTime.Month)
        udDate.RepeatInterval = 100

        udHour.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT
        udHour.Minimum = 0
        udHour.Maximum = 23
        udHour.RepeatInterval = 100

        udMinute.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT
        udMinute.Minimum = 0
        udMinute.Maximum = 59
        udMinute.RepeatInterval = 100

        udSecond.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT
        udSecond.Minimum = 0
        udSecond.Maximum = 59
        udSecond.RepeatInterval = 100

        ' 초기값 설정
        SetValues(m_dateTime)

        m_dialogResult = DialogResult.None
    End Sub

    Private Sub btnSet_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSet.Click
        ' 전달할 결과값 설정
        m_dateTimeInfo.strYear = udYear.Value.ToString()
        m_dateTimeInfo.strMonth = udMonth.Value.ToString()
        m_dateTimeInfo.strDate = udDate.Value.ToString()
        m_dateTimeInfo.strHour = udHour.Value.ToString()
        m_dateTimeInfo.strMinute = udMinute.Value.ToString()
        m_dateTimeInfo.strSecond = udSecond.Value.ToString()

        m_dialogResult = DialogResult.OK

        m_dateTime = New DateTime(CInt(udYear.Value), CInt(udMonth.Value), CInt(udDate.Value), CInt(udHour.Value), CInt(udMinute.Value), CInt(udSecond.Value))

        ' 현재 시스템의 날짜 및 시간을 설정
        SmartConfigs1.ControlPanel.SetSystemDateTime(m_dateTime)
    End Sub

    Private Sub btnReset_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnReset.Click
        SetValues(m_dateTime)
    End Sub

    Private Sub btnClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnClose.Click
        Close()
    End Sub

    Private Sub UpDown_OnUpButtonClick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles udMonth.OnUpButtonClick, udMonth.OnDownButtonClick
        SetMaxDate()
    End Sub

    ' 지정된 DateTime으로 값을 설정
    Private Sub SetValues(ByVal dateTime As DateTime)
        udYear.Value = dateTime.Year
        udMonth.Value = dateTime.Month

        SetMaxDate()

        udDate.Value = dateTime.Day
        udHour.Value = dateTime.Hour
        udMinute.Value = dateTime.Minute
        udSecond.Value = dateTime.Second
    End Sub

    ' Date가 최대 일수를 넘지 않도록 설정 
    Private Sub SetMaxDate()
        Dim iMaxDate As Integer = Date.DaysInMonth(CInt(udYear.Value), CInt(udMonth.Value))
        udDate.Maximum = iMaxDate

        If CInt(udDate.Value) > iMaxDate Then
            udDate.Value = iMaxDate
        End If
    End Sub
End Class